#
# spec file for package perl-HTTP-Daemon
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name HTTP-Daemon
Name:           perl-HTTP-Daemon
Version:        6.160.0
Release:        1.1
# 6.16 -> normalize -> 6.160.0
%define cpan_version 6.16
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Simple http server class
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/O/OA/OALDERS/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(HTTP::Date) >= 6
BuildRequires:  perl(HTTP::Request) >= 6
BuildRequires:  perl(HTTP::Response) >= 6
BuildRequires:  perl(HTTP::Status) >= 6
BuildRequires:  perl(IO::Socket::IP) >= 0.32
BuildRequires:  perl(LWP::MediaTypes) >= 6
BuildRequires:  perl(Module::Build)
BuildRequires:  perl(Module::Build::Tiny) >= 0.34
BuildRequires:  perl(Module::Metadata)
BuildRequires:  perl(Test::More) >= 0.98
BuildRequires:  perl(Test::Needs)
Requires:       perl(HTTP::Date) >= 6
Requires:       perl(HTTP::Request) >= 6
Requires:       perl(HTTP::Response) >= 6
Requires:       perl(HTTP::Status) >= 6
Requires:       perl(IO::Socket::IP) >= 0.32
Requires:       perl(LWP::MediaTypes) >= 6
Provides:       perl(HTTP::Daemon) = %{version}
%undefine       __perllib_provides
%{perl_requires}

%description
Instances of the 'HTTP::Daemon' class are HTTP/1.1 servers that listen on a
socket for incoming requests. The 'HTTP::Daemon' is a subclass of
'IO::Socket::IP', so you can perform socket operations directly on it too.

Please note that 'HTTP::Daemon' used to be a subclass of
'IO::Socket::INET'. To support IPv6, it switched the parent class to
'IO::Socket::IP' at version 6.05. See IPv6 SUPPORT for details.

The accept() method will return when a connection from a client is
available. The returned value will be an 'HTTP::Daemon::ClientConn' object
which is another 'IO::Socket::IP' subclass. Calling the get_request()
method on this object will read data from the client and return an
'HTTP::Request' object. The ClientConn object also provide methods to send
back various responses.

%prep
%autosetup -n %{cpan_name}-%{cpan_version} -p1

%build
perl Build.PL --installdirs=vendor
./Build build --flags=%{?_smp_mflags}

%check
./Build test

%install
./Build install --destdir=%{buildroot} --create_packlist=0
%perl_gen_filelist

%files -f %{name}.files
%doc Changes CONTRIBUTING README
%license LICENCE

%changelog
* Fri Jul 11 2025 Tina Müller <tina.mueller@suse.com>
- Normalize CPAN version
  See https://github.com/openSUSE/cpanspec/issues/47 for details
* Thu Mar  9 2023 Tina Müller <tina.mueller@suse.com>
- Remove patches
  - CVE-2022-31081-2.patch
  - CVE-2022-31081-Add-new-test-for-Content-Length-issues.patch
  - CVE-2022-31081.patch
  They were fixed upstream (bsc#1201157)
* Sat Feb 25 2023 Tina Müller <timueller+perl@suse.de>
- updated to 6.16
  see /usr/share/doc/packages/perl-HTTP-Daemon/Changes
  6.16      2023-02-24 03:07:14Z
  - Bump LWP::UserAgent to 6.37 in TestSuggests (GH#65) (Olaf Alders)
  6.15      2023-02-22 22:02:46Z
  - Fix CVE-2022-31081: Inconsistent Interpretation of HTTP Requests
    Correctly handle multiple Content-Length headers and its variants
    (Theo van Hoesel)
    Closes "Discrepancies in the Parsing of Content Length header ..." (GH#56)
    (blessingcharles)
  - kill test server with KILL rather than QUIT (GH#63) (Graham Knop)
  - Create TestServer test lib for running daemon process (GH#62) (Graham Knop)
  - Clean up tests (GH#61) (Graham Knop)
* Wed Jul 13 2022 Otto Hollmann <otto.hollmann@suse.com>
- Fix request smuggling in HTTP::Daemon
  (CVE-2022-31081, bsc#1201157)
  * CVE-2022-31081.patch
  * CVE-2022-31081-2.patch
  * CVE-2022-31081-Add-new-test-for-Content-Length-issues.patch
* Fri Mar  4 2022 Tina Müller <timueller+perl@suse.de>
- updated to 6.14
  see /usr/share/doc/packages/perl-HTTP-Daemon/Changes
  6.14      2022-03-03 20:47:51Z
  - Test using loopback rather than internet accessible address (GH#52)
    (Michal Josef Špaček)
  - Use GH Perl helpers for build and coverage jobs (GH#53) (Olaf Alders)
* Thu Feb 10 2022 Tina Müller <timueller+perl@suse.de>
- updated to 6.13
  see /usr/share/doc/packages/perl-HTTP-Daemon/Changes
  6.13      2022-02-09 20:39:12Z
  - Bump minimum IO::Socket::IP version to 0.32 (GH#50) (Olaf Alders)
* Fri Jun  5 2020 Tina Müller <timueller+perl@suse.de>
- updated to 6.12
  see /usr/share/doc/packages/perl-HTTP-Daemon/Changes
  6.12      2020-06-04 16:01:31Z
  - No changes since TRIAL release 6.11
  6.11      2020-06-03 14:47:21Z (TRIAL RELEASE)
  - An IPv6 zone separator must be URI-quoted (GH#47) (Petr Pisar and Olaf
    Alders)
* Wed May 27 2020 Tina Müller <timueller+perl@suse.de>
  updated to 6.10
  see /usr/share/doc/packages/perl-HTTP-Daemon/Changes
  6.10      2020-05-26 16:20:36Z
  - No changes since TRIAL release 6.09
  6.09      2020-05-25 16:52:14Z (TRIAL RELEASE)
  - Require IO::Socket::IP 0.25 so that HTTP::Tiny uses it (GH#45) (Shoichi Kaji)
  6.08      2020-05-22 15:26:00Z (TRIAL RELEASE)
  - In t/chunked.t, leave choosing IP address family to IO::Socket::IP (GH#42) (Shoichi Kaji)
  - Add "IPv6 SUPPORT" section to pod (GH#43) (Shoichi Kaji)
  - Use HTTP::Tiny 0.042+ for IPv6 support (GH#41) (Shoichi Kaji)
  6.07      2020-05-19 19:19:53Z (TRIAL RELEASE)
  - Prefer IP address for host in $d->url (GH#40) (Shoichi Kaji)
  - Improve documentation readability (GH#36) (Ferenc Erki)
* Fri Aug 30 2019 <timueller+perl@suse.de>
- updated to 6.06
  see /usr/share/doc/packages/perl-HTTP-Daemon/Changes
  6.06      2019-08-29 14:23:17Z
  - Delimit IPv6 numeric address with brackets and URI-quote an IPv6 zone
    separator in url() method output (GH#32) (Petr Pisar)
  - Handle undef and empty LocalAddr value in new() constructor as an
    unspecified address (GH#24, RT#123069) (Petr Pisar)
  - Use IO::Socket::IP for IPv6 support. (GH#31) (Chase Whitener)
* Sat Jul 27 2019 Stephan Kulow <coolo@suse.com>
- updated to 6.05
  see /usr/share/doc/packages/perl-HTTP-Daemon/Changes
  6.05      2019-07-26 20:41:05Z
  - Added the .perltidyrc from the libwww-perl distribution
  - Tidied the test suite with perltidy
  - Tidied Daemon.pm
  - Turned on EOL and tab tests
  - Removed obvious indirect object syntax in test suite
  - Added IPv6 support. (GH#24) Thanks, @ppisar and @intrigeri
  - Added IO::Socket::IP as a prerequisite rather than IO::Socket::INET
* Wed Apr  3 2019 Stephan Kulow <coolo@suse.com>
- updated to 6.04
  see /usr/share/doc/packages/perl-HTTP-Daemon/Changes
  6.04      2019-04-02 13:09:45Z
  - Remove circular dependency on LWP::RobotUA introduced in 6.02 (GH#29)
    (Olaf Alders)
* Tue Apr  2 2019 Stephan Kulow <coolo@suse.com>
- updated to 6.03
  see /usr/share/doc/packages/perl-HTTP-Daemon/Changes
* Mon Feb 20 2012 coolo@suse.com
- updated to 6.01
  If you bind localhost, don't trust gethostbyaddr() to resolve the
  address.  [RT#67247]
  Restore perl-5.8.1 compatiblity.
* Mon Mar 14 2011 vcizek@novell.com
- initial package 6.00
  * created by cpanspec 1.78.03
